Perf Report

# Performance Report

## run_id: 20251205T030413Z

## seed_data_rows: 100000

## [TEST bulk create from schemas]

## [TEST bulk update from dict]

## [TEST create from schemas]

## [TEST delete one by pk(id) + restore]

## [TEST get one by pk(id)]

## [TEST paging (page size:1000) with ORDER BY ID- keyset]

## [TEST paging (page size:1000) with ORDER BY ID- offset]

## [TEST count(*) with 3 WHERE]

## [TEST count(*)]

## [TEST fetch with 3 WHERE and 3 ORDER BY Conditions]

## [TEST fetch with 8 ORDER By Conditions]

## [TEST fetch with 8 WHERE Conditions]